@@ -659,10 +659,11 @@ class DataVars(object):
             len(self.__LevelsVar)>1:
             links = self.__getLinks(self.__LevelsVar)
             for name in links.keys():
-                #print name
                 for nameLink in links[name].keys():
                     val = self.__getattribute__(nameLink).Get()
                     self.__getattribute__(name).dependValues[nameLink] = val
+        if  self.__levelNumber == 0:
+            self.__LevelsVar = []
         return ret
 
     def Get(self, nameVar):
@@ -706,7 +707,7 @@ class DataVars(object):
     def __getLinks(self, lVar):
         """Получить список переменных и от каких переменных они зависят
 
-        на вход список [(уовень рекурсии, название переменной),]
+        на вход список [(уровень рекурсии, название переменной),]
         """
         links = {}
         frames = {}
@@ -818,7 +819,7 @@ class DataVars(object):
         retDelArea = True
         if not config.getAreaVars(header):
             retDelArea = config.delArea(header)
-        if retDelArea and retDelArea:
+        if retDelArea and retDelVar:
             return True
         else:
             return False
@@ -864,16 +865,20 @@ class DataVars(object):
         return act_section
 
     def flIniFile(self):
-        '''Заместить значение переменных значениями из ини файла
+        '''Заместить значение переменных значениями из ини файлов
 
         Возвращаемые значения:
-        True     переменные считаны
-        False    файл не был обнаружен
+        cловарь импортированных переменных -    переменные считаны
+        False  -  файл не был обнаружен
         '''
+        #Cловарь переменных из ini файлов
+        importVars = {}
         calculate_ini = self.__getPathCalculateIni()
         # активные секции (секции из которых будут использованы переменные)
         act_section = self.__getActiveSections()
         set_act_section = set(act_section)
+        i = 0
+        locations = ['remote','local','default']
         for name_calculate_ini in calculate_ini:
             # проверить сущестование ini файла
             if os.path.exists(name_calculate_ini):
@@ -885,19 +890,26 @@ class DataVars(object):
                     continue
                 # находим встречающиеся у обоих секции
                 act_sect = tuple(set(allsect)& set_act_section)
+                # словарь переменных для ini - файла
+                importFileVars = {}
                 # получаем все переменные из всех секций
                 for section in act_sect:
                     allvars = config.getAreaVars(section)
-                #allvars = config.getAreaVars(self.__getCurrentHeaderName())
                     if allvars == False:
                         return False
+                    # словарь переменных для ini - файла
+                    importFileVars = {}
                     # принудительно переписать все переменные окружения
                     # полученные из ini
                     for (k,v) in allvars.items():
                         k = k.encode("UTF-8")
-                        v = v.encode("UTF-8")
-                        self.Set(k, cl_utils.convertStrListDict(v), True)
-        return True
+                        value = cl_utils.convertStrListDict(v.encode("UTF-8"))
+                        self.Set(k, value, True)
+                        importFileVars[k] = value
+                if i < 3:
+                    importVars[locations[i]] = importFileVars
+            i += 1
+        return importVars
 
     def flServer(self, **args):
         '''Заполнить конфигурацию переменных, для ldap'''
