@@ -218,6 +218,8 @@ class fillVars(object, cl_base.glob_attr):
         # Португальский - pt_BR
         # Французский   - fr_FR
         # Немецкий      - de_DE
+        # Итальянский   - it_IT
+        # Польский      - pl_PL
         # Русский       - ru_RU
         # Испанский     - es_ES
         # Украинский    - uk_UA
@@ -225,6 +227,8 @@ class fillVars(object, cl_base.glob_attr):
         xkbDict = {'pt_BR':'br,us',
                 'fr_FR':'fr,us',
                 'de_DE':'de,us',
+                'it_IT':'it,us',
+                'pl_PL':'pl,us',
                 'ru_RU':'us,ru(winkeys)',
                 'es_ES':'es,us',
                 'uk_UA':'us,ua(winkeys)',
@@ -294,4 +298,17 @@ class fillVars(object, cl_base.glob_attr):
                 rootType = "hdd"
             return rootType
         else:
-            return ""
\ No newline at end of file
+            return ""
+
+    def get_hr_virtual(self):
+        """Название виртуальной машины (virtualbox, vmware, qemu)"""
+        pciLines = self._runos("""%s /usr/sbin/lspci"""%self.path_env)
+        virtSysDict = {'VirtualBox':'virtualbox',
+                       'VMware':'vmware',
+                       'Qumranet':'qemu'}
+        virtName = ''
+        for vName in virtSysDict.keys():
+            if filter(lambda x: vName in x, pciLines):
+                virtName = virtSysDict[vName]
+                break
+        return virtName
