@@ -79,5 +79,8 @@ class Data:
     # постфикс к названию системы
     os_linux_subname = {}
 
+    # название виртуальной машины (virtualbox, vmware, qemu)
+    hr_virtual = {}
+
     # версия системы
     os_linux_ver = {}
